@@ -68,9 +68,6 @@ class CreateScenario
         //! Set the number of signposts on the map
         void setNoSignposts(int number);
 
-        //! Set the number of stones on the map
-        void setNoStones (int number);
-
         //! Set the number of temples
         void setNoTemples(int number);
 
@@ -131,9 +128,6 @@ class CreateScenario
         //! Get the number of signposts on the map
         int getNoSignposts() const;
 
-        //! Get the number of stones on the map
-        int getNoStones () const;
-
         //! Get the number of temples
         int getNoTemples() const;
 
@@ -168,7 +162,7 @@ class CreateScenario
         bool distributePlayers();
 
         //! Setup city names and production
-        bool setupCities(bool quick_start);
+        bool setupCities(bool quick_start, bool cities_can_produce_allies);
 
         //! Setup temple names
         bool setupTemples();
@@ -189,6 +183,12 @@ class CreateScenario
           */
         bool loadNames(std::vector<std::string>& list, std::ifstream& namefile);
 
+        //! Set up rewards to be given out for quests, ruins and sages
+        bool setupRewards();
+        bool setupItemRewards();
+        bool setupRuinRewards();
+	bool setupMapRewards();
+
 
         //data
         //for map creation
