@@ -72,7 +72,10 @@ class Action
                 CITY_RENAME = 20,
                 CITY_VECTOR = 21,
                 FIGHT_ORDER = 22,
-		RESIGN = 23
+		RESIGN = 23,
+		ITEM_PLANT = 24,
+		PRODUCE_UNIT = 25,
+		PRODUCE_VECTORED_UNIT = 26
         };
                 
         
@@ -387,6 +390,7 @@ class Action_Reward : public Action
         bool fillData (Reward *);
     
     private:
+        bool load(std::string tag, XML_Helper *helper);
 	Reward *d_reward;
 	
 };
@@ -421,8 +425,7 @@ class Action_Equip : public Action
         enum Slot {
             NONE = 0,
             BACKPACK = 1,
-            GROUND = 2,
-            BODY = 3};
+            GROUND = 2};
         
         Action_Equip();
         Action_Equip(XML_Helper* helper);
@@ -431,13 +434,12 @@ class Action_Equip : public Action
         std::string dump() const;
         bool save(XML_Helper* helper) const;
 
-        bool fillData(Uint32 hero, Uint32 item, Slot slot, int index);
+        bool fillData(Uint32 hero, Uint32 item, Slot slot);
 
     private:
         Uint32 d_hero;
         Uint32 d_item;
         Uint32 d_slot;
-        int d_index;
 };
 
 //-----------------------------------------------------------------------------
@@ -544,5 +546,65 @@ class Action_Resign: public Action
         bool fillData();
 };
 
+//-----------------------------------------------------------------------------
+class Action_Plant: public Action
+{
+    public:
+        Action_Plant();
+        Action_Plant(XML_Helper* helper);
+        ~Action_Plant();
+
+        std::string dump() const;
+        bool save(XML_Helper* helper) const;
+
+        bool fillData(Uint32 hero, Uint32 item);
+
+    private:
+        Uint32 d_hero;
+        Uint32 d_item;
+};
+
+//-----------------------------------------------------------------------------
+class Action_Produce: public Action
+{
+    public:
+        Action_Produce();
+        Action_Produce(XML_Helper* helper);
+        ~Action_Produce();
+
+        std::string dump() const;
+        bool save(XML_Helper* helper) const;
+
+        bool fillData(Uint32 army_type, City *city, bool vectored);
+
+	Uint32 getArmyType() const {return d_army_type;}
+	Uint32 getCityId() const {return d_city;}
+	bool getVectored() const {return d_vectored;}
+    private:
+        Uint32 d_army_type;
+        Uint32 d_city;
+        bool d_vectored;
+};
+
         
+//-----------------------------------------------------------------------------
+class Action_ProduceVectored: public Action
+{
+    public:
+        Action_ProduceVectored();
+        Action_ProduceVectored(XML_Helper* helper);
+        ~Action_ProduceVectored();
+
+        std::string dump() const;
+        bool save(XML_Helper* helper) const;
+
+        bool fillData(Uint32 army_type, Vector <int>dest);
+
+	Uint32 getArmyType() const {return d_army_type;}
+	Vector<int> getDestination() const {return d_dest;}
+    private:
+        Uint32 d_army_type;
+        Vector<int> d_dest;
+};
+
 #endif //ACTION_H
