@@ -39,7 +39,7 @@
 #include "../gui/error-utils.h"
 
 #include "../ucompose.hpp"
-#include "../TileSet.h"
+#include "../tileset.h"
 #include "../GameMap.h"
 #include "../defs.h"
 #include "../sound.h"
@@ -60,8 +60,6 @@
 #include "../templelist.h"
 #include "../ruinlist.h"
 #include "../signpostlist.h"
-#include "../stonelist.h"
-#include "../stone.h"
 #include "../roadlist.h"
 #include "../bridgelist.h"
 #include "../portlist.h"
@@ -110,6 +108,8 @@ MainWindow::MainWindow()
     map_eventbox->signal_motion_notify_event().connect(
 	sigc::mem_fun(*this, &MainWindow::on_map_mouse_motion_event));
 
+    xml->get_widget("terrain_tile_style_hbox", terrain_tile_style_hbox);
+
     // setup pointer radiobuttons
     xml->get_widget("terrain_type_table", terrain_type_table);
 
@@ -117,6 +117,8 @@ MainWindow::MainWindow()
 			      EditorBigMap::POINTER, 1);
     setup_pointer_radiobutton(xml, "draw_1", "button_1x1",
 			      EditorBigMap::TERRAIN, 1);
+    setup_pointer_radiobutton(xml, "draw_2", "button_2x2",
+			      EditorBigMap::TERRAIN, 2);
     setup_pointer_radiobutton(xml, "draw_3", "button_3x3",
 			      EditorBigMap::TERRAIN, 3);
     setup_pointer_radiobutton(xml, "draw_stack", "button_stack",
@@ -125,8 +127,6 @@ MainWindow::MainWindow()
 			      EditorBigMap::RUIN, 1);
     setup_pointer_radiobutton(xml, "draw_signpost", "button_signpost",
 			      EditorBigMap::SIGNPOST, 1);
-    setup_pointer_radiobutton(xml, "draw_stone", "button_stone",
-			      EditorBigMap::STONE, 1);
     setup_pointer_radiobutton(xml, "draw_temple", "button_temple",
 			      EditorBigMap::TEMPLE, 1);
     setup_pointer_radiobutton(xml, "draw_road", "button_road",
@@ -162,13 +162,14 @@ MainWindow::MainWindow()
     xml->connect_clicked("edit_map_info_menuitem", 
 			 sigc::mem_fun(this, &MainWindow::on_edit_map_info_activated));
     
-#if 0
     xml->connect_clicked("fullscreen_menuitem", 
 			 sigc::mem_fun(this, &MainWindow::on_fullscreen_activated));
     xml->get_widget("fullscreen_menuitem", fullscreen_menuitem);
-    xml->connect_clicked("preferences_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_preferences_activated));
-#endif
+    xml->connect_clicked("smooth_map_menuitem", 
+			 sigc::mem_fun(this, 
+				       &MainWindow::on_smooth_map_activated));
+    xml->connect_clicked("smooth_screen_menuitem", sigc::mem_fun
+			 (this, &MainWindow::on_smooth_screen_activated));
 }
 
 MainWindow::~MainWindow()
@@ -207,7 +208,7 @@ void MainWindow::setup_terrain_radiobuttons()
     TileSet *tset = GameMap::getInstance()->getTileSet();
     Gtk::RadioButton::Group group;
     bool group_set = false;
-    const int no_columns = 3;
+    const int no_columns = 6;
     for (unsigned int i = 0; i < tset->size(); ++i)
     {
 	Tile *tile = (*tset)[i];
@@ -227,13 +228,12 @@ void MainWindow::setup_terrain_radiobuttons()
 	terrain_type_table->attach(*item.button, column, column + 1,
 				   row, row + 1, Gtk::SHRINK);
 	item.button->signal_toggled().connect(
-	    sigc::mem_fun(this, &MainWindow::on_pointer_radiobutton_toggled));
+	    sigc::mem_fun(this, &MainWindow::on_terrain_radiobutton_toggled));
 
-	Glib::RefPtr<Gdk::Pixbuf> pic = to_pixbuf(tile->getSurface(0));
+	SDL_Surface *surf = (*(*tile)[0])[0]->getPixmap();
+	Glib::RefPtr<Gdk::Pixbuf> pic = to_pixbuf(surf)->scale_simple(20, 20, Gdk::INTERP_NEAREST);
 	item.button->add(*manage(new Gtk::Image(pic)));
 
-	tooltips.set_tip(*item.button, tile->getName());
-
 	item.terrain = tile->getType();
 	terrain_items.push_back(item);
     }
@@ -300,26 +300,32 @@ bool MainWindow::on_delete_event(GdkEventAny *e)
 
 void MainWindow::show_initial_map()
 {
-    set_filled_map(112, 156, Tile::GRASS);
+    set_filled_map(112, 156, Tile::WATER, "default");
     setup_terrain_radiobuttons();
+    remove_tile_style_buttons();
+    setup_tile_style_buttons(Tile::GRASS);
 }
 
-void MainWindow::set_filled_map(int width, int height, int fill_style)
+void MainWindow::set_filled_map(int width, int height, int fill_style, std::string tileset)
 {
     clear_map_state();
 
     GameMap::deleteInstance();
     GameMap::setWidth(width);
     GameMap::setHeight(height);
-    GameMap::getInstance("default");
+    GameMap::getInstance(tileset);
 
     // sets up the lists
     game_scenario.reset(new GameScenario(_("Untitled"), _("No description"), true));
+    //zip past the player IDs (+1 for neutral)
+    for (unsigned int i = 0; i < MAX_PLAYERS + 1; i++)
+      fl_counter->getNextId();
+
 
     // ...however we need to do some of the setup by hand. We need to create a
     // neutral player to give cities a player upon creation...
     Uint32 armyset = Armysetlist::getInstance()->getArmysets()[0];
-    Player* neutral = new AI_Dummy(_("Neutral"), armyset, Player::get_color_for_neutral());
+    Player* neutral = new AI_Dummy(_("Neutral"), armyset, Player::get_color_for_neutral(), MAX_PLAYERS);
     neutral->setType(Player::AI_DUMMY);
     Playerlist::getInstance()->push_back(neutral);
     Playerlist::getInstance()->setNeutral(neutral);
@@ -343,15 +349,16 @@ void MainWindow::set_random_map(int width, int height,
 				int grass, int water, int swamp, int forest,
 				int hills, int mountains,
 				int cities, int ruins, int temples,
-				int signposts, int stones)
+				int signposts, std::string tileset)
 {
     clear_map_state();
 
     GameMap::deleteInstance();
     GameMap::setWidth(width);
     GameMap::setHeight(height);
-    GameMap::getInstance("default");
+    GameMap::getInstance(tileset);
 
+    //zip past the player IDs
     if (fl_counter)
 	delete fl_counter;
     fl_counter = new FL_Counter(MAX_PLAYERS + 1);
@@ -359,7 +366,7 @@ void MainWindow::set_random_map(int width, int height,
     // We need to create a neutral player to give cities a player upon
     // creation...
     Uint32 armyset = Armysetlist::getInstance()->getArmysets()[0];
-    Player* neutral = new AI_Dummy(_("Neutral"), armyset, Player::get_color_for_neutral(), 0);
+    Player* neutral = new AI_Dummy(_("Neutral"), armyset, Player::get_color_for_neutral(), MAX_PLAYERS);
     neutral->setType(Player::AI_DUMMY);
     Playerlist::getInstance()->push_back(neutral);
     Playerlist::getInstance()->setNeutral(neutral);
@@ -373,7 +380,6 @@ void MainWindow::set_random_map(int width, int height,
     gen.setNoRuins(ruins);
     gen.setNoTemples(temples);
     gen.setNoSignposts(signposts);
-    gen.setNoStones(stones);
     
     // if sum > 100 (percent), divide everything by a factor, the numeric error
     // is said to be grass
@@ -417,9 +423,6 @@ void MainWindow::set_random_map(int width, int height,
 	    case Maptile::SIGNPOST:
 		Signpostlist::getInstance()->push_back(Signpost(Vector<int>(i,j)));
 		break;
-	    case Maptile::STONE:
-		Stonelist::getInstance()->push_back(Stone(Vector<int>(i,j)));
-		break;
 	    case Maptile::ROAD:
 		Roadlist::getInstance()->push_back(Road(Vector<int>(i,j)));
 		break;
@@ -461,6 +464,8 @@ bool MainWindow::on_sdl_mouse_button_event(GdkEventButton *e)
     {
 	button_event = e;	// save it for later use
 	bigmap->mouse_button_event(to_input_event(e));
+	if (smallmap.get())
+	  smallmap->draw();
     }
     
     return true;
@@ -545,10 +550,11 @@ void MainWindow::on_new_map_activated()
 	    set_random_map(d.map.width, d.map.height,
 			   d.map.grass, d.map.water, d.map.swamp, d.map.forest,
 			   d.map.hills, d.map.mountains,
-			   d.map.cities, d.map.ruins, d.map.temples, d.map.signposts,
-			   d.map.stones);
+			   d.map.cities, d.map.ruins, d.map.temples, 
+			   d.map.signposts, d.map.tileset);
 	else
-	    set_filled_map(d.map.width, d.map.height, d.map.fill_style);
+	    set_filled_map(d.map.width, d.map.height, d.map.fill_style, 
+			   d.map.tileset);
     }
 }
 
@@ -659,6 +665,84 @@ void MainWindow::on_fullscreen_activated()
     else
 	window->unfullscreen();
 }
+void MainWindow::remove_tile_style_buttons()
+{
+  Glib::ListHandle<Gtk::Widget*> children = 
+    terrain_tile_style_hbox->get_children();
+  if (!children.empty()) 
+    {
+      Glib::ListHandle<Gtk::Widget*>::iterator child = children.begin();
+      for (; child != children.end(); child++)
+	terrain_tile_style_hbox->remove(**child);
+    }
+  tile_style_items.clear();
+}
+void MainWindow::setup_tile_style_buttons(Tile::Type terrain)
+{
+  Gtk::RadioButton::Group group;
+  //iterate through tilestyles of a certain TERRAIN tile
+  TileSet *tileset = GameMap::getInstance()->getTileSet();
+  Uint32 index = tileset->getIndex(terrain);
+  Tile *tile = (*tileset)[index];
+  if (tile == NULL)
+    return;
+	  
+  TileStyleItem auto_item;
+  auto_item.button = manage(new Gtk::RadioButton);
+  terrain_tile_style_hbox->pack_start(*manage(auto_item.button), 
+				      Gtk::PACK_SHRINK, 0, 0);
+  auto_item.button->set_label(_("Auto"));
+  auto_item.button->property_draw_indicator() = false;
+	  
+  auto_item.button->signal_toggled().connect
+    (sigc::mem_fun(this, &MainWindow::on_tile_style_radiobutton_toggled));
+
+  auto_item.tile_style_id = -1;
+  group = auto_item.button->get_group();
+  tile_style_items.push_back(auto_item);
+
+  for (unsigned int i = 0; i < tile->size(); i++)
+    {
+      TileStyleSet *tilestyleset = (*tile)[i];
+      //loop through tile style sets
+      for (unsigned int j = 0; j < tilestyleset->size(); j++)
+	{
+	  //now loop through the tile styles
+	  TileStyle *tilestyle = (*tilestyleset)[j];
+
+	  //let's make a button
+	  TileStyleItem item;
+	  item.button = manage(new Gtk::RadioButton);
+	  item.button->set_group(group);
+	  item.button->property_draw_indicator() = false;
+
+	  terrain_tile_style_hbox->pack_start(*manage(item.button), 
+					      Gtk::PACK_SHRINK, 0, 0);
+	  item.button->signal_toggled().connect
+	    (sigc::mem_fun(this, 
+			   &MainWindow::on_tile_style_radiobutton_toggled));
+
+	  SDL_Surface *surf = tilestyle->getPixmap();
+	  Glib::RefPtr<Gdk::Pixbuf> pic = to_pixbuf(surf);
+	  item.button->add(*manage(new Gtk::Image(pic)));
+	  item.tile_style_id = tilestyle->getId();
+
+	  tile_style_items.push_back(item);
+	}
+    }
+
+  terrain_tile_style_hbox->show_all();
+}
+void MainWindow::on_tile_style_radiobutton_toggled()
+{
+  on_pointer_radiobutton_toggled();
+}
+void MainWindow::on_terrain_radiobutton_toggled()
+{
+  remove_tile_style_buttons();
+  setup_tile_style_buttons(get_terrain());
+  on_pointer_radiobutton_toggled();
+}
 
 void MainWindow::on_pointer_radiobutton_toggled()
 {
@@ -677,8 +761,10 @@ void MainWindow::on_pointer_radiobutton_toggled()
     }
     
     if (bigmap.get())
-	bigmap->set_pointer(pointer, size, get_terrain());
+	bigmap->set_pointer(pointer, size, get_terrain(),
+			    get_tile_style_id());
     terrain_type_table->set_sensitive(pointer == EditorBigMap::TERRAIN);
+    terrain_tile_style_hbox->set_sensitive(pointer == EditorBigMap::TERRAIN);
 }
 
 Tile::Type MainWindow::get_terrain()
@@ -697,6 +783,22 @@ Tile::Type MainWindow::get_terrain()
     return terrain;
 }
 
+int MainWindow::get_tile_style_id()
+{
+  int tile_style_id = -1;
+  for (std::vector<TileStyleItem>::iterator i = tile_style_items.begin(),
+       end = tile_style_items.end(); i != end; ++i)
+    {
+	if (i->button->get_active())
+	  {
+	    tile_style_id = i->tile_style_id;
+	    break;
+	  }
+    }
+
+    return tile_style_id;
+}
+
 void MainWindow::on_smallmap_changed(SDL_Surface *map)
 {
     map_image->property_pixbuf() = to_pixbuf(map);
@@ -818,3 +920,13 @@ void MainWindow::popup_dialog_for_object(Object *object)
 	bigmap->draw();
     }
 }
+void MainWindow::on_smooth_map_activated()
+{
+  GameMap::getInstance()->applyTileStyles(0, 0, GameMap::getHeight(), 
+					  GameMap::getWidth(), true);
+  bigmap->draw();
+}
+void MainWindow::on_smooth_screen_activated()
+{
+  bigmap->smooth_view();
+}
