@@ -52,6 +52,7 @@
 #include "army-gains-level-dialog.h"
 #include "hero-dialog.h"
 #include "sage-dialog.h"
+#include "ruin-rewarded-dialog.h"
 #include "hero-offer-dialog.h"
 #include "quest-report-dialog.h"
 #include "quest-assigned-dialog.h"
@@ -64,6 +65,7 @@
 #include "item-bonus-dialog.h"
 #include "history-report-dialog.h"
 #include "report-dialog.h"
+#include "triumphs-dialog.h"
 
 #include "../ucompose.hpp"
 #include "../defs.h"
@@ -98,6 +100,7 @@
 #include "../reward.h"
 #include "../Configuration.h"
 #include "../GameMap.h"
+#include "../Item.h"
 
 
 GameWindow::GameWindow()
@@ -111,8 +114,8 @@ GameWindow::GameWindow()
     xml->get_widget("window", w);
     window.reset(w);
 
-    w->signal_delete_event().connect(
-	sigc::mem_fun(*this, &GameWindow::on_delete_event));
+      w->signal_delete_event().connect
+       (sigc::mem_fun(*this, &GameWindow::on_delete_event));
 
     xml->get_widget("sdl_container", sdl_container);
     xml->get_widget("stack_info_box", stack_info_box);
@@ -132,27 +135,28 @@ GameWindow::GameWindow()
     xml->get_widget("map_eventbox", map_eventbox);
     map_eventbox->add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
 			     Gdk::POINTER_MOTION_MASK);
-    map_eventbox->signal_button_press_event().connect(
-	sigc::mem_fun(*this, &GameWindow::on_map_mouse_button_event));
-    map_eventbox->signal_button_release_event().connect(
-	sigc::mem_fun(*this, &GameWindow::on_map_mouse_button_event));
-    map_eventbox->signal_motion_notify_event().connect(
-	sigc::mem_fun(*this, &GameWindow::on_map_mouse_motion_event));
+      map_eventbox->signal_button_press_event().connect
+       (sigc::mem_fun(*this, &GameWindow::on_map_mouse_button_event));
+      map_eventbox->signal_button_release_event().connect
+       (sigc::mem_fun(*this, &GameWindow::on_map_mouse_button_event));
+      map_eventbox->signal_motion_notify_event().connect
+       (sigc::mem_fun(*this, &GameWindow::on_map_mouse_motion_event));
 
     // the stats
-    xml->get_widget("stats_label", stats_label);
-    stats_text = stats_label->get_text();
     Gtk::Image *image;
     xml->get_widget("cities_stats_image", image);
-    image->property_file() = File::getMiscFile("various/items.png");
+    image->property_file() = File::getMiscFile("various/smallcity.png");
     xml->get_widget("gold_stats_image", image);
-    image->property_file() = File::getMiscFile("various/items.png");
+    image->property_file() = File::getMiscFile("various/smalltreasury.png");
     xml->get_widget("income_stats_image", image);
-    image->property_file() = File::getMiscFile("various/items.png");
+    image->property_file() = File::getMiscFile("various/smallincome.png");
+    xml->get_widget("upkeep_stats_image", image);
+    image->property_file() = File::getMiscFile("various/smallupkeep.png");
     
     xml->get_widget("cities_stats_label", cities_stats_label);
     xml->get_widget("gold_stats_label", gold_stats_label);
     xml->get_widget("income_stats_label", income_stats_label);
+    xml->get_widget("upkeep_stats_label", upkeep_stats_label);
     xml->get_widget("turn_label", turn_label);
     xml->get_widget("turn_hbox", turn_hbox);
     xml->get_widget("shield_image_0", shield_image[0]);
@@ -169,6 +173,7 @@ GameWindow::GameWindow()
     xml->get_widget("center_button", center_button);
     xml->get_widget("defend_button", defend_button);
     xml->get_widget("park_button", park_button);
+    xml->get_widget("deselect_button", deselect_button);
     xml->get_widget("search_button", search_button);
     xml->get_widget("move_button", move_button);
     xml->get_widget("move_all_button", move_all_button);
@@ -181,6 +186,7 @@ GameWindow::GameWindow()
     center_button->add(*manage(new Gtk::Image(button_images[5])));
     defend_button->add(*manage(new Gtk::Image(button_images[6])));
     park_button->add(*manage(new Gtk::Image(button_images[1])));
+    deselect_button->add(*manage(new Gtk::Image(button_images[7])));
     search_button->add(*manage(new Gtk::Image(button_images[9])));
     move_button->add(*manage(new Gtk::Image(button_images[3])));
     move_all_button->add(*manage(new Gtk::Image(button_images[4])));
@@ -240,11 +246,17 @@ GameWindow::GameWindow()
 			 sigc::mem_fun(*this, &GameWindow::on_item_bonus_activated));
     xml->connect_clicked("production_report_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_production_report_activated));
+    xml->connect_clicked("triumphs_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_triumphs_activated));
     d_quick_fights = false;
 }
 
 GameWindow::~GameWindow()
 {
+  std::list<sigc::connection>::iterator it = connections.begin();
+  for (; it != connections.end(); it++) 
+    (*it).disconnect();
+  connections.clear();
     clear_army_buttons();
 }
 
@@ -254,6 +266,7 @@ void GameWindow::show()
     center_button->show_all();
     defend_button->show_all();
     park_button->show_all();
+    deselect_button->show_all();
     search_button->show_all();
     move_button->show_all();
     move_all_button->show_all();
@@ -284,18 +297,20 @@ void GameWindow::init(int width, int height)
     sdl_widget->set_flags(Gtk::CAN_FOCUS);
 
     sdl_widget->grab_focus();
-    sdl_widget->add_events(Gdk::KEY_PRESS_MASK |
+    sdl_widget->add_events(Gdk::KEY_PRESS_MASK | 
 		  Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
 	          Gdk::POINTER_MOTION_MASK);
 
+    sdl_widget->signal_key_press_event().connect(
+	sigc::mem_fun(*this, &GameWindow::on_sdl_key_event));
+    sdl_widget->signal_key_release_event().connect(
+	sigc::mem_fun(*this, &GameWindow::on_sdl_key_event));
     sdl_widget->signal_button_press_event().connect(
 	sigc::mem_fun(*this, &GameWindow::on_sdl_mouse_button_event));
     sdl_widget->signal_button_release_event().connect(
 	sigc::mem_fun(*this, &GameWindow::on_sdl_mouse_button_event));
     sdl_widget->signal_motion_notify_event().connect(
 	sigc::mem_fun(*this, &GameWindow::on_sdl_mouse_motion_event));
-    sdl_widget->signal_key_press_event().connect(
-	sigc::mem_fun(*this, &GameWindow::on_sdl_key_event));
     
     // connect to the special signal that signifies that a new surface has been
     // generated and attached to the widget
@@ -312,7 +327,7 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
 
     // then fill the other players
     int c = 0;
-    int army_id = Armysetlist::getInstance()->file_names[g.army_theme];
+    int army_id = Armysetlist::getInstance()->getArmysetId(g.army_theme);
     for (std::vector<GameParameters::Player>::const_iterator
 	     i = g.players.begin(), end = g.players.end();
 	 i != end; ++i, ++c) {
@@ -334,7 +349,7 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
 	creator.addPlayer(i->name, army_id, Player::get_color_for_no(c), type);
     }
 
-    // first insert the neutral player
+    // the neutral player must come last so it has the highest id among players
     creator.addNeutral(_("Neutral"), army_id, Player::get_color_for_neutral(),
 		       Player::AI_DUMMY);
 
@@ -351,7 +366,6 @@ create_and_dump_scenario(const std::string &file, const GameParameters &g)
 
     int area = g.map.width * g.map.height;
     creator.setNoSignposts(int(area * (g.map.grass / 100.0) * 0.0030));
-    creator.setNoStones(int(area * (g.map.grass / 100.0) * 0.0022));
 
     // tell it the dimensions
     creator.setWidth(g.map.width);
@@ -392,6 +406,7 @@ void GameWindow::load_game(std::string file_path)
     setup_game(file_path);
     setup_signals();
     game->loadGame();
+    game->redraw();
 }
 
 void GameWindow::setup_button(Gtk::Button *button,
@@ -432,6 +447,9 @@ void GameWindow::setup_signals()
   setup_button(park_button,
 	       sigc::mem_fun(game.get(), &Game::park_selected_stack),
 	       game->can_park_selected_stack);
+  setup_button(deselect_button,
+	       sigc::mem_fun(game.get(), &Game::deselect_selected_stack),
+	       game->can_deselect_selected_stack);
   setup_button(search_button,
 	       sigc::mem_fun(game.get(), &Game::search_selected_stack),
 	       game->can_search_selected_stack);
@@ -495,6 +513,9 @@ void GameWindow::setup_signals()
   connections.push_back
     (game->smallmap_changed.connect
      (sigc::mem_fun(*this, &GameWindow::on_smallmap_changed)));
+  connections.push_back
+    (game->get_smallmap().view_slid.connect
+     (sigc::mem_fun(*this, &GameWindow::on_smallmap_slid)));
   connections.push_back
     (game->stack_info_changed.connect
      (sigc::mem_fun(*this, &GameWindow::on_stack_info_changed)));
@@ -507,6 +528,9 @@ void GameWindow::setup_signals()
   connections.push_back
     (game->ruin_searched.connect
      (sigc::mem_fun(*this, &GameWindow::on_ruin_searched)));
+  connections.push_back
+    (game->sage_visited.connect
+     (sigc::mem_fun(*this, &GameWindow::on_sage_visited)));
   connections.push_back
     (game->fight_started.connect
      (sigc::mem_fun(*this, &GameWindow::on_fight_started)));
@@ -567,6 +591,9 @@ void GameWindow::setup_signals()
   connections.push_back
     (game->player_died.connect
      (sigc::mem_fun(*this, &GameWindow::on_player_died)));
+  connections.push_back
+    (game->advice_asked.connect
+     (sigc::mem_fun(*this, &GameWindow::on_advice_asked)));
 
   // misc callbacks
   QuestsManager *q = QuestsManager::getInstance();
@@ -582,8 +609,6 @@ void GameWindow::setup_signals()
 	(game->get_bigmap().cursor_changed.connect
 	 (sigc::mem_fun(*this, &GameWindow::on_bigmap_cursor_changed)));
     }
-  else
-    printf("couldn't setup cursor changed event\n");
 
 }
 
@@ -591,7 +616,7 @@ void GameWindow::setup_game(std::string file_path)
 {
   stop_game();
 
-  bool broken;
+  bool broken = false;
   GameScenario* game_scenario = new GameScenario(file_path, broken);
 
   if (broken)
@@ -627,7 +652,10 @@ bool GameWindow::on_sdl_mouse_button_event(GdkEventButton *e)
 bool GameWindow::on_sdl_mouse_motion_event(GdkEventMotion *e)
 {
   if (game.get())
-    game->get_bigmap().mouse_motion_event(to_input_event(e));
+    {
+      game->get_bigmap().mouse_motion_event(to_input_event(e));
+      sdl_widget->grab_focus();
+    }
   return true;
 }
 
@@ -641,12 +669,15 @@ void GameWindow::on_bigmap_cursor_changed(GraphicsCache::CursorType cursor)
 
 bool GameWindow::on_sdl_key_event(GdkEventKey *e)
 {
-#if 0
-  // keypresses are not implemented in the bigmap at this point,
-  // to_input_event must also be defined to something sensible
-  if (game.get())
-    game->get_bigmap().key_press_event(to_input_event(e));
-#endif
+  static int left_shift_down = 0;
+  static int right_shift_down = 0;
+  if (e->keyval == GDK_Shift_L) 
+    left_shift_down = !left_shift_down;
+  else if (e->keyval == GDK_Shift_R)
+    right_shift_down = !right_shift_down;
+
+  if (e->keyval == GDK_Shift_L || e->keyval == GDK_Shift_R)
+    game->get_bigmap().set_shift_key_down (right_shift_down || left_shift_down);
 
   return true;
 }
@@ -692,6 +723,7 @@ void GameWindow::on_sdl_surface_changed()
 
 void GameWindow::on_load_game_activated()
 {
+  return;
   Gtk::FileChooserDialog chooser(*window.get(), _("Choose Game to Load"));
   Gtk::FileFilter sav_filter;
   sav_filter.add_pattern("*.sav");
@@ -767,7 +799,7 @@ void GameWindow::on_quit_activated()
 
   if (end) {
     stop_game();
-    quit_requested.emit();
+    game_ended.emit();
   }
 }
 
@@ -891,7 +923,7 @@ void GameWindow::on_preferences_activated()
 {
   PreferencesDialog d;
   d.set_parent_window(*window.get());
-  d.run();
+  d.run(game.get());
 }
 
 void GameWindow::on_group_ungroup_activated()
@@ -1006,6 +1038,13 @@ void GameWindow::on_winner_history_activated()
   d.run();
 }
 
+void GameWindow::on_triumphs_activated()
+{
+  TriumphsDialog d(Playerlist::getActiveplayer());
+  d.set_parent_window(*window.get());
+  d.run();
+}
+
 void GameWindow::stop_game()
 {
   Sound::getInstance()->disableBackground();
@@ -1019,6 +1058,7 @@ void GameWindow::stop_game()
 
 void GameWindow::on_game_over(Player *winner)
 {
+
   std::auto_ptr<Gtk::Dialog> dialog;
 
   Glib::RefPtr<Gnome::Glade::Xml> xml
@@ -1053,12 +1093,8 @@ void GameWindow::on_game_over(Player *winner)
   Gtk::Label *label;
   xml->get_widget("label", label);
   Glib::ustring s;
-  s += String::ucompose(_("%1 has taken over the world!"), winner->getName());
-  if (winner->getType() == Player::HUMAN)
-    {
-      s += " ";
-      s += _("Congratulations!");
-    }
+  s += String::ucompose(_("Congratulations to %1 for conquering the world!"), 
+	winner->getName());
   label->set_text(s);
 
   dialog->show_all();
@@ -1087,6 +1123,18 @@ void GameWindow::on_player_died(Player *player)
   Glib::ustring s;
   s += String::ucompose(_("The rule of %1 has permanently ended!"),
 			player->getName());
+  if (Playerlist::getInstance()->countHumanPlayersAlive() == 0 &&
+      player->getType() == Player::HUMAN)
+    {
+      s += "\n";
+      s += _("No further human resistance is possible");
+      s += "\n";
+      s += _("but the battle will continue!");
+      s += "\n";
+      s += _("Press `CTRL-P' to stop the war");
+      s += "\n";
+      s += _("and visit the sites of thy old battles.");
+    }
   label->set_text(s);
 
   dialog->show_all();
@@ -1145,14 +1193,6 @@ bool GameWindow::on_army_button_event(GdkEventButton *e,
   return false;
 }
 
-void GameWindow::on_army_button_has_size()
-{
-  // fix height to prevent flickering
-  int height = stack_info_box->get_height();
-  stack_info_box->property_height_request() = height;
-  stats_box->property_height_request() = height;
-}
-
 void GameWindow::clear_army_buttons()
 {
   for (army_buttons_type::iterator i = army_buttons.begin(),
@@ -1195,23 +1235,24 @@ void GameWindow::ensure_one_army_button_active()
 
 void GameWindow::on_sidebar_stats_changed(SidebarStats s)
 {
-  Glib::ustring n = String::ucompose(
-				     stats_text, s.name, s.gold, s.income, s.cities, s.units);
-
-  stats_label->set_text(n);
-
   cities_stats_label->set_text(String::ucompose("%1", s.cities));
   gold_stats_label->set_text(String::ucompose("%1", s.gold));
   income_stats_label->set_text(String::ucompose("%1", s.income));
+  upkeep_stats_label->set_text(String::ucompose("%1", s.upkeep));
   turn_label->set_text(String::ucompose("Turn %1", s.turns + 1));
 }
 
 void GameWindow::on_smallmap_changed(SDL_Surface *map)
 {
-  //while (g_main_context_iteration(NULL, FALSE)); //doEvents
   map_image->property_pixbuf() = to_pixbuf(map);
 }
 
+void GameWindow::on_smallmap_slid(Rectangle view)
+{
+  on_smallmap_changed(game->get_smallmap().get_surface());
+  while (g_main_context_iteration(NULL, FALSE)); //doEvents
+}
+
 void GameWindow::on_stack_info_changed(Stack *s)
 {
   clear_army_buttons();
@@ -1231,6 +1272,12 @@ void GameWindow::on_stack_info_changed(Stack *s)
 
 void GameWindow::show_stats()
 {
+  Armysetlist *al = Armysetlist::getInstance();
+  int height = al->getTileSize(Playerlist::getActiveplayer()->getArmyset());
+  height += turn_label->get_height();
+  height += 20;
+  stack_info_box->get_parent()->property_height_request() = height;
+  stats_box->get_parent()->property_height_request() = height;
   stack_info_container->hide();
   stats_box->show();
 }
@@ -1241,7 +1288,7 @@ void GameWindow::fill_in_group_info (Stack *s)
   GraphicsCache *gc = GraphicsCache::getInstance();
   SDL_Surface *terrain = gc->getMoveBonusPic(bonus, s->hasShip());
   terrain_image->property_pixbuf() = to_pixbuf(terrain);
-  group_moves_label->set_text(String::ucompose(_("Group\nMoves\n%1"),
+  group_moves_label->set_text(String::ucompose("%1",
 					       s->getGroupMoves()));
   group_ungroup_toggle->set_active(s->isGrouped());
 }
@@ -1279,9 +1326,6 @@ void GameWindow::show_stack(Stack *s)
       toggle->signal_button_release_event().connect(
 						    sigc::bind(sigc::mem_fun(*this, &GameWindow::on_army_button_event),
 							       toggle, army), false);
-      toggle->signal_size_allocate().connect_notify(
-						    sigc::hide(sigc::mem_fun(*this, &GameWindow::on_army_button_has_size)));
-
       // add it
       stack_info_box->pack_start(*toggle, Gtk::PACK_SHRINK);
       army_buttons.push_back(toggle);
@@ -1368,6 +1412,14 @@ void GameWindow::on_sage_visited (Ruin *ruin, Stack *stack)
   SageDialog d(stack->getFirstHero()->getPlayer(), 
 	       static_cast<Hero*>(stack->getFirstHero()), ruin);
   d.set_parent_window(*window.get());
+  Reward *reward = d.run();
+  ruin->setReward(reward);
+}
+
+void GameWindow::on_ruin_rewarded (Reward_Ruin *reward)
+{
+  RuinRewardedDialog d(reward);
+  d.set_parent_window(*window.get());
   d.run();
 }
 
@@ -1375,7 +1427,10 @@ void GameWindow::on_ruin_searched(Ruin *ruin, Stack *stack, Reward *reward)
 {
   std::auto_ptr<Gtk::Dialog> dialog;
   if (ruin->hasSage())
-    return on_sage_visited (ruin, stack);
+    {
+      if (reward->getType() == Reward::RUIN)
+	return on_ruin_rewarded(static_cast<Reward_Ruin*>(reward));
+    }
 
   Glib::RefPtr<Gnome::Glade::Xml> xml
     = Gnome::Glade::Xml::create(get_glade_path() + "/ruin-searched-dialog.glade");
@@ -1397,15 +1452,27 @@ void GameWindow::on_ruin_searched(Ruin *ruin, Stack *stack, Reward *reward)
 
   Glib::ustring s = label->get_text();
   s += "\n\n";
+  s += String::ucompose("%1 finds ", stack->getFirstHero()->getName());
   if (reward->getType() == Reward::GOLD)
-    s += String::ucompose("%1 finds %2 gp.", stack->getFirstHero()->getName(), 
-			  dynamic_cast<Reward_Gold*>(reward)->getGold());
+    {
+      Reward_Gold *gold = dynamic_cast<Reward_Gold*>(reward);
+      s += String::ucompose("%1 gold pieces.", gold->getGold());
+    }
   else if (reward->getType() == Reward::ALLIES)
-    s += String::ucompose("%1 gets %2 allies.", stack->getFirstHero()->getName(), 
-			  dynamic_cast<Reward_Allies*>(reward)->getNoOfAllies());
+    {
+      Reward_Allies *allies = dynamic_cast<Reward_Allies*>(reward);
+      s += String::ucompose("%1 allies.", allies->getNoOfAllies());
+    }
   else if (reward->getType() == Reward::ITEM)
-    s += String::ucompose("%1 gets the %2.", stack->getFirstHero()->getName(), 
-			  dynamic_cast<Reward_Item*>(reward)->getItem()->getName());
+    {
+      Reward_Item *item = dynamic_cast<Reward_Item*>(reward);
+      s += String::ucompose("the %1.", item->getItem()->getName());
+    }
+  else if (reward->getType() == Reward::MAP)
+    {
+      Reward_Map *map = dynamic_cast<Reward_Map*>(reward);
+      s += String::ucompose("the %2.", map->getLocation()->getName());
+    }
 
   label->set_text(s);
 
@@ -1804,7 +1871,7 @@ void GameWindow::on_city_pillaged(City *city, int gold, int pillaged_army_type)
   if (gold == 0)
     {
       SDL_Surface *s
-	= GraphicsCache::getInstance()->getArmyPic(as, 0, player, 1, NULL);
+	= GraphicsCache::getInstance()->getArmyPic(as, 0, player, NULL);
       Glib::RefPtr<Gdk::Pixbuf> empty_pic
 	= Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, s->w, s->h);
       empty_pic->fill(0x00000000);
@@ -1814,7 +1881,7 @@ void GameWindow::on_city_pillaged(City *city, int gold, int pillaged_army_type)
   else
     {
       Glib::RefPtr<Gdk::Pixbuf> pic;
-      pic = to_pixbuf(gc->getArmyPic(as, pillaged_army_type, player, 1, NULL));
+      pic = to_pixbuf(gc->getArmyPic(as, pillaged_army_type, player, NULL));
       pillaged_army_type_image->set(pic);
       pillaged_army_type_cost_label->set_text(String::ucompose("%1 gp", gold));
     }
@@ -1876,7 +1943,7 @@ void GameWindow::on_city_sacked(City *city, int gold, std::list<Uint32> sacked_t
 
   Glib::RefPtr<Gdk::Pixbuf> pic;
   SDL_Surface *surf
-    = GraphicsCache::getInstance()->getArmyPic(as, 0, player, 1, NULL);
+    = GraphicsCache::getInstance()->getArmyPic(as, 0, player, NULL);
   Glib::RefPtr<Gdk::Pixbuf> empty_pic
     = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, surf->w, surf->h);
   empty_pic->fill(0x00000000);
@@ -1900,7 +1967,7 @@ void GameWindow::on_city_sacked(City *city, int gold, std::list<Uint32> sacked_t
 	  sack_image = sacked_army_3_image;
 	  break;
 	}
-      pic = to_pixbuf(gc->getArmyPic(as, *it, player, 1, NULL));
+      pic = to_pixbuf(gc->getArmyPic(as, *it, player, NULL));
       sack_image->set(pic);
       const Army *a = 
 	Armysetlist::getInstance()->getArmy (player->getArmyset(), *it);
@@ -2117,7 +2184,7 @@ void GameWindow::on_quest_expired(Quest *quest)
   xml->get_widget("label", label);
   Glib::ustring s;
   s += String::ucompose(_("%1 did not complete the quest."),
-			quest->getHero()->getName());
+			quest->getHeroName());
   s += "\n\n";
 
   // add messages from the quest
@@ -2148,3 +2215,81 @@ void GameWindow::on_plant_standard_activated ()
 {
   Playerlist::getActiveplayer()->heroPlantStandard(NULL);
 }
+    
+void GameWindow::on_advice_asked(float percent)
+{
+  //we asked for advice on a fight, and we're being told that we 
+  //have a PERCENT chance of winning the fight
+  std::auto_ptr<Gtk::Dialog> dialog;
+
+  Glib::RefPtr<Gnome::Glade::Xml> xml
+    = Gnome::Glade::Xml::create(get_glade_path() + "/military-advisor-dialog.glade");
+
+  Gtk::Dialog *d;
+  xml->get_widget("dialog", d);
+  dialog.reset(d);
+  dialog->set_transient_for(*window.get());
+
+  dialog->set_title(_("Advisor!"));
+
+  Gtk::Label *label;
+  xml->get_widget("label", label);
+  Glib::ustring s;
+
+  int num = rand() % 5;
+  if (num == 0)
+    s += _("My Good Lord!");
+  else if (num == 1)
+    s += _("Great and Worthy Lord!");
+  else if (num == 2)
+    s += _("O Champion of Justice!");
+  else if (num == 3)
+    s += _("O Mighty Leader!");
+  else if (num == 4)
+    s += _("O Great Warlord!");
+  s += "\n";
+
+  num = rand() % 7;
+  if (num == 0)
+    s += _("This battle will surely be");
+  else if (num == 1)
+    s += _("A battle here would be");
+  else if (num == 2)
+    s += _("I believe this battle will surely be");
+  else if (num == 3)
+    s += _("This battle would be");
+  else if (num == 4)
+    s += _("A battle here would be");
+  else if (num == 5)
+    s += _("I believe this battle will be");
+  else if (num == 6)
+    s += _("This battle shall be");
+  s += "\n";
+
+
+  if (percent >= 90.0)
+    s += _("as simple as butchering sleeping cattle!");
+  else if (percent >= 80.0)
+    s += _("an easy victory!  We cannot lose!");
+  else if (percent >= 70.0)
+    s += _("a comfortable victory");
+  else if (percent >= 60.0)
+    s += _("a hard fought victory! But we shall win!");
+  else if (percent >= 50.0)
+    s += _("very evenly matched!");
+  else if (percent >= 40.0)
+    s += _("difficult but not impossible to win!");
+  else if (percent >= 30.0)
+    s += _("a brave choice! I leave it to thee!");
+  else if (percent >= 20.0)
+    s += _("a foolish decision!");
+  else if (percent >= 10.0)
+    s += _("sheerest folly!  Thou shouldst not attack!");
+  else
+    s += _("complete and utter suicide!");
+  label->set_text(s);
+
+  dialog->show_all();
+  dialog->run();
+  return;
+}
