@@ -19,6 +19,7 @@
 #include <vector>
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
+#include <sigc++/connection.h>
 #include <gtkmm/window.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/eventbox.h>
@@ -114,12 +115,11 @@ class GameWindow: public sigc::trackable
     Gtk::Image *terrain_image;
     Gtk::Box *stats_box;
     Gtk::Image *map_image;
-    Gtk::Label *stats_label;
-    Glib::ustring stats_text;	// the text into which the stats are inserted
 
     Gtk::Label *cities_stats_label;
     Gtk::Label *gold_stats_label;
     Gtk::Label *income_stats_label;
+    Gtk::Label *upkeep_stats_label;
     Gtk::Label *turn_label;
     Gtk::HBox *turn_hbox;
     Gtk::Image *shield_image[MAX_PLAYERS];
@@ -129,6 +129,7 @@ class GameWindow: public sigc::trackable
     Gtk::Button *center_button;
     Gtk::Button *defend_button;
     Gtk::Button *park_button;
+    Gtk::Button *deselect_button;
     Gtk::Button *search_button;
     Gtk::Button *move_button;
     Gtk::Button *move_all_button;
@@ -186,6 +187,7 @@ class GameWindow: public sigc::trackable
     void on_event_history_activated();
     void on_gold_history_activated();
     void on_winner_history_activated();
+    void on_triumphs_activated();
 
     void on_message_requested(std::string msg);
     
@@ -197,7 +199,6 @@ class GameWindow: public sigc::trackable
     void on_group_toggled(Gtk::ToggleButton *toggle);
     bool on_army_button_event(GdkEventButton *e,
 			      Gtk::ToggleButton *toggle, Army *army);
-    void on_army_button_has_size();
     void clear_army_buttons();
     void update_army_buttons();
     void ensure_one_army_button_active();
@@ -208,12 +209,14 @@ class GameWindow: public sigc::trackable
     // game callbacks
     void on_sidebar_stats_changed(SidebarStats s);
     void on_smallmap_changed(SDL_Surface *map);
+    void on_smallmap_slid(Rectangle view);
     void on_bigmap_cursor_changed(GraphicsCache::CursorType cursor);
     void on_stack_info_changed(Stack *s);
     void on_map_tip_changed(Glib::ustring tip, MapTipPosition pos);
     void on_stack_tip_changed(Stack *s, MapTipPosition pos);
     void on_ruin_searched(Ruin *ruin, Stack *s, Reward *reward);
     void on_sage_visited(Ruin *ruin, Stack *s);
+    void on_ruin_rewarded(Reward_Ruin *reward);
     void on_fight_started(Fight &fight);
     void on_ruinfight_started(Stack *attackers, Stack *defenders);
     void on_ruinfight_finished(Fight::Result result);
@@ -234,6 +237,7 @@ class GameWindow: public sigc::trackable
     void on_game_loaded(Player *player);
     void on_game_over(Player *winner);
     void on_player_died(Player *player);
+    void on_advice_asked(float percent);
 
     // quest manager callbacks
     void on_quest_completed(Quest *quest, Reward *reward);
